
# unfolded.map_sdk

[![Build Status](https://travis-ci.org/Unfolded Inc/unfolded_jupyter.svg?branch=master)](https://travis-ci.org/Unfolded Inc/unfolded_jupyter)
[![codecov](https://codecov.io/gh/Unfolded Inc/unfolded_jupyter/branch/master/graph/badge.svg)](https://codecov.io/gh/Unfolded Inc/unfolded_jupyter)


Unfolded Map SDK for Jupyter (Python).

## Installation

You can install using `pip`:

```bash
pip install unfolded.map_sdk
```

If you are using Jupyter Notebook 5.2 or earlier, you may also need to enable
the nbextension:

```bash
jupyter nbextension install --py --symlink --sys-prefix unfolded.map_sdk
jupyter nbextension enable --py --sys-prefix unfolded.map_sdk
```
